package com.ruoyi.custclient.service.impl;

import java.util.List;

import com.ruoyi.custclient.domain.LabelCode;
import com.ruoyi.custclient.mapper.LabelCodeMapper;
import com.ruoyi.custclient.service.ILabelCodeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 标签组codeService业务层处理
 * 
 * @author zhangyubo
 * @date 2024-10-16
 */
@Service
public class LabelCodeServiceImpl implements ILabelCodeService
{
    @Autowired
    private LabelCodeMapper labelCodeMapper;

    /**
     * 查询标签组code
     * 
     * @param id 标签组code主键
     * @return 标签组code
     */
    @Override
    public LabelCode selectLabelCodeById(Long id)
    {
        return labelCodeMapper.selectLabelCodeById(id);
    }

    /**
     * 查询标签组code列表
     * 
     * @param labelCode 标签组code
     * @return 标签组code
     */
    @Override
    public List<LabelCode> selectLabelCodeList(LabelCode labelCode)
    {
        return labelCodeMapper.selectLabelCodeList(labelCode);
    }

    /**
     * 新增标签组code
     * 
     * @param labelCode 标签组code
     * @return 结果
     */
    @Override
    public int insertLabelCode(LabelCode labelCode)
    {
        return labelCodeMapper.insertLabelCode(labelCode);
    }

    /**
     * 修改标签组code
     * 
     * @param labelCode 标签组code
     * @return 结果
     */
    @Override
    public int updateLabelCode(LabelCode labelCode)
    {
        return labelCodeMapper.updateLabelCode(labelCode);
    }

    /**
     * 批量删除标签组code
     * 
     * @param ids 需要删除的标签组code主键
     * @return 结果
     */
    @Override
    public int deleteLabelCodeByIds(Long[] ids)
    {
        return labelCodeMapper.deleteLabelCodeByIds(ids);
    }

    /**
     * 删除标签组code信息
     * 
     * @param id 标签组code主键
     * @return 结果
     */
    @Override
    public int deleteLabelCodeById(Long id)
    {
        return labelCodeMapper.deleteLabelCodeById(id);
    }
}
